Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(20)

Unified Diff: views/controls/menu/submenu_view.h

Issue 270067: Converts some uses of native_view to native_window. This is necessitated... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: views/controls/menu/submenu_view.h
===================================================================
--- views/controls/menu/submenu_view.h (revision 28706)
+++ views/controls/menu/submenu_view.h (working copy)
@@ -74,7 +74,7 @@
// Shows the menu at the specified location. Coordinates are in screen
// coordinates. max_width gives the max width the view should be.
- void ShowAt(gfx::NativeView parent, const gfx::Rect& bounds, bool do_capture);
+ void ShowAt(gfx::NativeWindow parent, const gfx::Rect& bounds, bool do_capture);
// Closes the menu, destroying the host.
void Close();
@@ -112,8 +112,8 @@
// Returns the container for the SubmenuView.
MenuScrollViewContainer* GetScrollViewContainer();
- // Returns the NativeView host of the menu, or NULL if not showing.
- gfx::NativeView native_view() const;
+ // Returns the NativeWindow host of the menu, or NULL if not showing.
+ gfx::NativeWindow native_window() const;
// Padding around the edges of the submenu.
static const int kSubmenuBorderSize;

Powered by Google App Engine
This is Rietveld 408576698